@@ -12,8 +12,11 @@ use Pugs::Grammar::Rule;
 use Pugs::Runtime::Match;
 use Pugs::Emitter::Rule::Perl5;
 use Pugs::Emitter::Rule::Perl5::Ratchet;
+use Pugs::Compiler::RegexPerl5;
 
+use Carp 'croak';
 use Data::Dumper;
+use Symbol 'qualify_to_ref';
 
 sub new { $_[0] }
 
@@ -25,6 +28,9 @@ sub compile {
 
     my ( $class, $rule_source, $param ) = @_;
 
+    return Pugs::Compiler::RegexPerl5->compile( $rule_source, $param )
+        if exists $param->{P5} || exists $param->{Perl5};
+
     my $self = { source => $rule_source };
 
     #print Dumper @_;
@@ -133,6 +139,19 @@ sub match {
     return Pugs::Runtime::Match->new( { bool => 0 } );   # XXX - fix?
 }
 
+sub install {
+  my($class, $name, @etc) = @_;
+
+  ## If we have a fully qualified name, use that, otherwise extrapolate.
+  my $rule = index($name, '::') > -1 ? $name : scalar(caller)."::$name";
+  my $slot = qualify_to_ref($rule);
+
+  croak "Can't install regex '$name' as '$rule' already exists"
+    if *$slot{CODE};
+
+  *$slot = $class->compile(@etc)->code;
+}
+
 sub _str { defined $_[0] ? $_[0] : 'undef' }
 sub _quot { 
     my $s = $_[0];
