@@ -24,8 +24,9 @@ sub call_subrule {
 
 sub call_constant {
     my $const = $_[0];
-    my $len = length( $const );
-    $const = $_[0] eq '\\' ? '\\\\' : $_[0];  # XXX - generalize
+    my $len = length( eval "'$const'" );
+    $const = ( $_[0] eq $_ ? "chr(".ord($_).")" : $_[0] )
+        for qw( \ ' );     # '
     return
     "$_[1] ( ( substr( \$s, \$pos, $len ) eq '$const' ) 
 $_[1]     ? do { \$pos $direction= $len; 1 }
@@ -37,7 +38,7 @@ sub call_perl5 {
     my $const = $_[0];
     return
     "$_[1] ( ( substr( \$s, \$pos ) =~ m/^$const/s )  
-$_[1]     ? do { \$pos $direction= 1; 1 }    # XXX - get pos from regex
+$_[1]     ? do { \$pos $direction= length \$&; 1 }
 $_[1]     : 0
 $_[1] )";
 }
@@ -79,9 +80,12 @@ sub emit_rule {
     die "unknown node: ", Dumper( $n )
         unless ref( $n ) eq 'HASH';
     #print "NODE ", Dumper($n);
-    my ( $k, $v ) = each %$n;
+    my ($k) = keys %$n;
+    my $v = $$n{$k};
+    #my ( $k, $v ) = each %$n;
     # XXX - use real references
     no strict 'refs';
+    print "NODE ", Dumper($k), ", ", Dumper($v);
     my $code = &$k( $v, $tab );
     return $code;
 }
@@ -313,9 +317,9 @@ $_[1]       my \%named;
 $_[1]       my \$capture;
 $_[1]       \$bool = 0 unless
 $program;
-$_[1]       { str => \\\$s, from => \\\$from, match => \\\@match, named => \\\%named, bool => \$bool, to => \\(0+\$pos), capture => \\\$capture }
+$_[1]       { str => \\\$s, from => \\\$from, match => \\\@match, named => \\\%named, bool => \\\$bool, to => \\(0+\$pos), capture => \\\$capture }
 $_[1]     };
-$_[1]     my \$bool = \$hash->{'bool'};
+$_[1]     my \$bool = \${\$hash->{'bool'}};
 .
         $gen_match = "bless \\\$hash, 'Pugs::Runtime::Match::Ratchet'";
 	$post_match = "";
@@ -419,8 +423,19 @@ sub metasyntax {
     my $prefix = substr( $cmd, 0, 1 );
     if ( $prefix eq '@' ) {
         # XXX - wrap @array items - see end of Pugs::Grammar::Rule
+        # TODO - param list
         return 
-            "$_[1] ... alternation( \\$cmd )\n";
+            "$_[1] do {\n" . 
+            "$_[1]    my \$match;\n" . 
+            "$_[1]    for my \$subrule ( $cmd ) {\n" . 
+            "$_[1]        \$match = " . 
+                call_subrule( '$subrule', '', () ) . ";\n" .
+            "$_[1]        last if \$match;\n" . 
+            "$_[1]    }\n" .
+            "$_[1]    my \$bool = (!\$match != 1);\n" . 
+            "$_[1]    \$pos = \$match->to if \$bool;\n" . 
+            "$_[1]    \$bool;\n" . 
+            "$_[1] }";
     }
     if ( $prefix eq '$' ) {
         if ( $cmd =~ /::/ ) {
